package
Version:
v0.9.3
Opens a new window with list of versions in this module.
Published: Apr 28, 2025
License: MIT
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Singleton[T any] struct {
}
func (s *Singleton[T]) Get(initFunc func() T) T
func (s *Singleton[T]) GetWithCloser(initFunc func() (T, func(), error)) (T, func())
Source Files
¶
Click to show internal directories.
Click to hide internal directories.